py-import-cycles
================

Detect import cycles in Python projects

Installation
------------

The py-import-cycles package is available on PyPI: `python3 -m pip install --user py-import-cycles`

Usage
-----

* `python3 -m py_import_cycles --version`
* `python3 -m py_import_cycles --help`
* `python3 -m py_import_cycles --project-path /path/to/project`
